==> haskell-tf-random-0.5-960-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tf-random.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tf-random
version:              0.5
visibility:           public
id:                   tf-random-0.5-J5ZBqxDZTtf1lMTNC7osRx
key:                  tf-random-0.5-J5ZBqxDZTtf1lMTNC7osRx
license:              BSD-3-Clause
maintainer:           Michał Pałka <michal.palka@chalmers.se>
author:               Michał Pałka <michal.palka@chalmers.se>
synopsis:             High-quality splittable pseudorandom number generator
description:
    This package contains an implementation of a high-quality splittable pseudorandom number generator. The generator is based on a cryptographic hash function built on top of the ThreeFish block cipher. See the paper /Splittable Pseudorandom Number Generators Using Cryptographic Hashing/ by Claessen, Pałka for details and the rationale of the design.

    The package provides the following:

    * A splittable PRNG that implements the standard '\''System.Random.RandomGen'\'' class.

    * The generator also implements an alternative version of the '\''System.Random.TF.Gen.RandomGen'\'' class (exported from "System.Random.TF.Gen"), which requires the generator to return pseudorandom integers from the full 32-bit range, and contains an n-way split function.

    * An alternative version of the @Random@ class is provided, which is linked to the new @RandomGen@ class, together with @Random@ instances for some integral types.

    * Two functions for initialising the generator with a non-deterministic seed: one using the system time, and one using the @\/dev\/urandom@ UNIX special file.

    The package uses an adapted version of the reference C implementation of ThreeFish from the reference package of the Skein hash function (<https://www.schneier.com/skein.html>), originally written by Doug Whiting.

    Please note that even though the generator provides very high-quality pseudorandom numbers, it has not been designed with cryptographic applications in mind.

category:             Random
abi:                  58f83502b0abd546b20f5511ce078717
exposed:              True
exposed-modules:
    System.Random.TF System.Random.TF.Gen System.Random.TF.Init
    System.Random.TF.Instances

import-dirs:          /usr/lib/ghc-9.4.8/site-local/tf-random-0.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tf-random-0.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tf-random-0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tf-random
hs-libraries:         HStf-random-0.5-J5ZBqxDZTtf1lMTNC7osRx
depends:
    base-4.17.2.1 primitive-0.9.1.0-8nzcMUtKW4yAfvV7oeRfvP
    random-1.2.1.3-DyhQJBMZMiBKToaxsRw6jM time-1.12.2

haddock-interfaces:   /usr/share/doc/haskell-tf-random/html/tf-random.haddock
haddock-html:         /usr/share/doc/haskell-tf-random/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tf-random-0.5-964-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tf-random.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tf-random
version:              0.5
visibility:           public
id:                   tf-random-0.5-JmxkTXpNkGOJMVvdKO8f4e
key:                  tf-random-0.5-JmxkTXpNkGOJMVvdKO8f4e
license:              BSD-3-Clause
maintainer:           Michał Pałka <michal.palka@chalmers.se>
author:               Michał Pałka <michal.palka@chalmers.se>
synopsis:             High-quality splittable pseudorandom number generator
description:
    This package contains an implementation of a high-quality splittable pseudorandom number generator. The generator is based on a cryptographic hash function built on top of the ThreeFish block cipher. See the paper /Splittable Pseudorandom Number Generators Using Cryptographic Hashing/ by Claessen, Pałka for details and the rationale of the design.

    The package provides the following:

    * A splittable PRNG that implements the standard '\''System.Random.RandomGen'\'' class.

    * The generator also implements an alternative version of the '\''System.Random.TF.Gen.RandomGen'\'' class (exported from "System.Random.TF.Gen"), which requires the generator to return pseudorandom integers from the full 32-bit range, and contains an n-way split function.

    * An alternative version of the @Random@ class is provided, which is linked to the new @RandomGen@ class, together with @Random@ instances for some integral types.

    * Two functions for initialising the generator with a non-deterministic seed: one using the system time, and one using the @\/dev\/urandom@ UNIX special file.

    The package uses an adapted version of the reference C implementation of ThreeFish from the reference package of the Skein hash function (<https://www.schneier.com/skein.html>), originally written by Doug Whiting.

    Please note that even though the generator provides very high-quality pseudorandom numbers, it has not been designed with cryptographic applications in mind.

category:             Random
abi:                  6043a2acfe0ec908e1563ae963c1e928
exposed:              True
exposed-modules:
    System.Random.TF System.Random.TF.Gen System.Random.TF.Init
    System.Random.TF.Instances

import-dirs:          /usr/lib/ghc-9.4.8/site-local/tf-random-0.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tf-random-0.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tf-random-0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tf-random
hs-libraries:         HStf-random-0.5-JmxkTXpNkGOJMVvdKO8f4e
depends:
    base-4.17.2.1 primitive-0.9.1.0-2TXcUIi8rPN1Wdwcs7XGaB
    random-1.2.1.3-6fLOERitWZgLekqeklTRBb time-1.12.2

haddock-interfaces:   /usr/share/doc/haskell-tf-random/html/tf-random.haddock
haddock-html:         /usr/share/doc/haskell-tf-random/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
